# -*- coding: utf-8 -*-
"""
This file defines tasks for the Invoke tool: http://www.pyinvoke.org

Basic usage::

    inv -l               # list all available tasks
    inv --help task      # show help for task

"""
# pragma: nocover
from __future__ import print_function

import glob
import os
import re
import sys
import invoke
from invoke import task       # invoke==1.2.0

DIRNAME = os.path.dirname(__file__)


@task
def version(ctx):
    """Print the current version number.
    """
    os.chdir(DIRNAME)
    ctx.run('python setup.py --version')


@task
def setversion(ctx, version):
    """Set the version number
    """
    os.chdir(DIRNAME)
    with open('setup.py', 'r') as fp:
        txt = fp.read()

    with open('setup.py', 'w') as fp:
        fp.write(re.sub(
            r'^VERSION\s*=\s*.*?$', "VERSION = '%s'" % version,
            txt,
            flags=re.MULTILINE
        ))
    print("Changed version in setup.py to:", version)


@task(
    help={
        'clean': 'remove the build/ and dist/ directory before starting',
        'wheel': 'build wheel (in addition to sdist)',
        'upload': 'upload to PyPI after building'
    }
)
def build(ctx, clean=False, wheel=True, upload=False):
    """Build and publish (inv --help build for details)
    """
    os.chdir(DIRNAME)
    if clean:
        ctx.run('rmdir dist /s /q', warn=True)
        ctx.run('rmdir build /s /q', warn=True)

    targets = 'sdist'
    if wheel:
        targets += ' bdist_wheel'
    ctx.run("python setup.py " + targets)

    print("Check generated .whl files..")
    ctx.run("twine check dist/*")

    # ctx.run("python setup.py build_sphinx")
    if upload:
        ctx.run("twine upload dist/*")


# individual tasks that can be run from this project
ns = invoke.Collection(
    version,
    setversion,
    build
)
ns.configure({
    'run': {
        'echo': True
    }
})



#!/usr/bin/env python

from distribute_setup import use_setuptools
use_setuptools()

PROJECT = 'virtualenvwrapper-win'
AUTHOR = 'David Marble'
EMAIL = 'davidmarble@gmail.com'
DESCRIPTION = ('Port of Doug Hellmann\'s virtualenvwrapper '
               'to Windows batch scripts')
VERSION = '1.2.7'
PROJECT_URL = 'https://github.com/davidmarble/%s/' % (PROJECT)
scripts_loc = 'scripts/'
scripts = [
    'add2virtualenv.bat',
    'cd-.bat',
    'cdproject.bat',
    'cdsitepackages.bat',
    'cdvirtualenv.bat',
    'folder_delete.bat',
    'lssitepackages.bat',
    'lsvirtualenv.bat',
    'mkproject.bat',
    'mkvirtualenv.bat',
    'rmvirtualenv.bat',
    'setprojectdir.bat',
    'toggleglobalsitepackages.bat',
    'whereis.bat',
    'workon.bat',
    'virtualenvwrapper.bat',
    'vwenv.bat',
]

import os
import sys
import shutil
import codecs
from setuptools import setup
from setuptools.command.install import install as _setuptools_install

long_description = ''
try:
    long_description = open('README.rst', 'rt').read()
except IOError:
    pass

try:
    long_description += '\n' + open('CHANGELOG.rst', 'rt').read()
except IOError:
    pass


PYTHONHOME = sys.exec_prefix


setup(
    name=PROJECT,
    version=VERSION,

    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/x-rst',

    author=AUTHOR,
    author_email=EMAIL,
    url=PROJECT_URL,
    license="BSD 3-clause",
    keywords="setuptools deployment installation distutils virtualenv virtualenvwrapper",

    platforms=['WIN32', 'WIN64', ],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Win32 (MS Windows)',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.4',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Intended Audience :: Developers',
        'Environment :: Console', ],

    scripts=[scripts_loc + script for script in scripts],

    install_requires=['virtualenv', ],

    # extras
    # pywin==0.2

    zip_safe=False,
)
